@@ -20,7 +20,7 @@ require 5.004;
 
 use strict;
 use vars qw($VERSION @ISA);
-$VERSION = '0.4101';
+$VERSION = '0.4102';
 
 ######################################################################
 
@@ -63,9 +63,9 @@ use CGI::WPM::Base 0.41;
 	$globals->file_path_root( cwd() );  # let us default to current working dir
 	$globals->file_path_delimiter( $^O=~/Mac/i ? ":" : $^O=~/Win/i ? "\\" : "/" );
 
-	require CGI::WPM::SimpleUserIO;
-	my $io = CGI::WPM::SimpleUserIO->new( 1 );
-	$io->give_user_input_to_cgi_portable( $globals );
+	require CGI::Portable::AdapterCGI;
+	my $io = CGI::Portable::AdapterCGI->new();
+	$io->fetch_user_input( $globals );
 
 	if( $globals->user_query_param( 'debugging' ) eq 'on' ) {
 		$globals->is_debug( 1 );
@@ -102,7 +102,7 @@ __endquote
 	} );
 	$globals->search_and_replace_url_path_tokens( '__url_path__' );
 
-	$io->send_user_output_from_cgi_portable( $globals );
+	$io->send_user_output( $globals );
 
 	1;
 
@@ -519,6 +519,6 @@ Address comments, suggestions, and bug reports to B<perl@DarrenDuncan.net>.
 
 =head1 SEE ALSO
 
-perl(1), CGI::Portable, CGI::WPM::Base, CGI::WPM::SimpleUserIO.
+perl(1), CGI::Portable, CGI::WPM::Base, CGI::Portable::AdapterCGI.
 
 =cut
