@@ -17,7 +17,7 @@ require 5.004;
 
 use strict;
 use vars qw($VERSION @ISA);
-$VERSION = '0.41';
+$VERSION = '0.4101';
 
 ######################################################################
 
@@ -65,9 +65,9 @@ use CGI::WPM::Base 0.41;
 	$globals->set_prefs( \%CONFIG );
 	$globals->call_component( 'CGI::WPM::Static' );
 
-	require CGI::WPM::SimpleUserIO;
-	my $io = CGI::WPM::SimpleUserIO->new();
-	$io->send_user_output_from_cgi_portable( $globals );
+	require CGI::Portable::AdapterCGI;
+	my $io = CGI::Portable::AdapterCGI->new();
+	$io->send_user_output( $globals );
 
 	1;
 
@@ -206,6 +206,6 @@ Address comments, suggestions, and bug reports to B<perl@DarrenDuncan.net>.
 
 =head1 SEE ALSO
 
-perl(1), CGI::Portable, CGI::WPM::Base, CGI::WPM::SimpleUserIO.
+perl(1), CGI::Portable, CGI::WPM::Base, CGI::Portable::AdapterCGI.
 
 =cut
